@@ -21,7 +21,7 @@
 #include <QColor>
 #include <QPixmap>
 
-#include <KConfigCore/KConfigGroup>
+#include <KConfigGroup>
 
 
 namespace K3b {
@@ -114,7 +114,7 @@ namespace K3b {
 
     public:
         explicit ThemeManager( QObject* parent = 0 );
-        ~ThemeManager();
+        ~ThemeManager() override;
 
         QList<Theme*> themes() const;
 
