@@ -24,7 +24,7 @@
 #include <QDialog>
 #include <QLabel>
 
-#include <KIOCore/KIO/Global>
+#include <KIO/Global>
 
 class QProgressBar;
 class QLabel;
@@ -42,7 +42,7 @@ namespace K3b {
         Q_OBJECT
 
     public:
-        ~DataUrlAddingDialog();
+        ~DataUrlAddingDialog() override;
 
         /**
          * shows DataUrlAddingDialog in non-blocking fashion
